==> jc-1.4.0.tar.gz: soot/jimple/parser/node/ACmpgBinop.h <==
// public final class soot.jimple.parser.node.ACmpgBinop

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 525a0407cfed3db4 soot_jimple_parser_node_ACmpgBinop
// @dep_class 73de4e43969ada95 soot_jimple_parser_node_Node
// @dep_class b86441297795c006 soot_jimple_parser_node_PBinop

// header file dependencies
// @dep_header soot_jimple_parser_node_PBinop

#include "soot/jimple/parser/node/PBinop.h"

#ifndef _JC_soot_jimple_parser_node_ACmpgBinop_H_
#define _JC_soot_jimple_parser_node_ACmpgBinop_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_jimple_parser_node_Node$object;
struct _jc_soot_jimple_parser_node_Switch$object;
struct _jc_soot_jimple_parser_node_TCmpg$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_node_ACmpgBinop$sub_refs	_jc_soot_jimple_parser_node_ACmpgBinop$sub_refs;
typedef struct _jc_soot_jimple_parser_node_ACmpgBinop$sub_nonrefs	_jc_soot_jimple_parser_node_ACmpgBinop$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_node_ACmpgBinop$refs	_jc_soot_jimple_parser_node_ACmpgBinop$refs;
typedef struct _jc_soot_jimple_parser_node_ACmpgBinop$nonrefs	_jc_soot_jimple_parser_node_ACmpgBinop$nonrefs;
typedef struct _jc_soot_jimple_parser_node_ACmpgBinop$object	_jc_soot_jimple_parser_node_ACmpgBinop$object;

typedef const struct _jc_soot_jimple_parser_node_ACmpgBinop$vmethods	_jc_soot_jimple_parser_node_ACmpgBinop$vmethods;
typedef const struct _jc_soot_jimple_parser_node_ACmpgBinop$vtable	_jc_soot_jimple_parser_node_ACmpgBinop$vtable;
typedef const struct _jc_soot_jimple_parser_node_ACmpgBinop$vtype	_jc_soot_jimple_parser_node_ACmpgBinop$vtype;

// Constructors
extern void _jc_soot_jimple_parser_node_ACmpgBinop$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpgBinop$object *);
extern void _jc_soot_jimple_parser_node_ACmpgBinop$method$_init$3d21b85fff626a14(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpgBinop$object *, struct _jc_soot_jimple_parser_node_TCmpg$object *);

// Virtual methods
extern void _jc_soot_jimple_parser_node_ACmpgBinop$method$apply$7d8f74ce7309b216(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpgBinop$object *, struct _jc_object *);
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_parser_node_ACmpgBinop$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpgBinop$object *);
extern struct _jc_soot_jimple_parser_node_TCmpg$object *_jc_soot_jimple_parser_node_ACmpgBinop$method$getCmpg$a5fb676a25d763b4(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpgBinop$object *);
extern void _jc_soot_jimple_parser_node_ACmpgBinop$method$removeChild$f5fdaab456b88f05(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpgBinop$object *, struct _jc_soot_jimple_parser_node_Node$object *);
extern void _jc_soot_jimple_parser_node_ACmpgBinop$method$replaceChild$f0df61b776b15826(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpgBinop$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *);
extern void _jc_soot_jimple_parser_node_ACmpgBinop$method$setCmpg$f31782e2d53b32dd(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpgBinop$object *, struct _jc_soot_jimple_parser_node_TCmpg$object *);
extern struct _jc_java_lang_String$object *_jc_soot_jimple_parser_node_ACmpgBinop$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpgBinop$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_parser_node_ACmpgBinop$method_info$apply$7d8f74ce7309b216;
extern _jc_method _jc_soot_jimple_parser_node_ACmpgBinop$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_parser_node_ACmpgBinop$method_info$getCmpg$a5fb676a25d763b4;
extern _jc_method _jc_soot_jimple_parser_node_ACmpgBinop$method_info$removeChild$f5fdaab456b88f05;
extern _jc_method _jc_soot_jimple_parser_node_ACmpgBinop$method_info$replaceChild$f0df61b776b15826;
extern _jc_method _jc_soot_jimple_parser_node_ACmpgBinop$method_info$setCmpg$f31782e2d53b32dd;
extern _jc_method _jc_soot_jimple_parser_node_ACmpgBinop$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_parser_node_ACmpgBinop$vmethods {
	void	(*apply$7d8f74ce7309b216)(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpgBinop$object *, struct _jc_object *);
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpgBinop$object *);
	struct _jc_soot_jimple_parser_node_TCmpg$object	*(*getCmpg$a5fb676a25d763b4)(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpgBinop$object *);
	void	(*removeChild$f5fdaab456b88f05)(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpgBinop$object *, struct _jc_soot_jimple_parser_node_Node$object *);
	void	(*replaceChild$f0df61b776b15826)(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpgBinop$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *);
	void	(*setCmpg$f31782e2d53b32dd)(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpgBinop$object *, struct _jc_soot_jimple_parser_node_TCmpg$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpgBinop$object *);
};

// Vtable
struct _jc_soot_jimple_parser_node_ACmpgBinop$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_node_Node$vmethods	soot_jimple_parser_node_Node;
	_jc_soot_jimple_parser_node_PBinop$vmethods	soot_jimple_parser_node_PBinop;
	_jc_soot_jimple_parser_node_ACmpgBinop$vmethods	soot_jimple_parser_node_ACmpgBinop;
};

// Vtype
struct _jc_soot_jimple_parser_node_ACmpgBinop$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_node_ACmpgBinop$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_ACmpgBinop$sub_refs {
	struct _jc_soot_jimple_parser_node_TCmpg$object	*__5fcmpg__5f;
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_node_ACmpgBinop$refs {
    _jc_soot_jimple_parser_node_ACmpgBinop$sub_refs	soot_jimple_parser_node_ACmpgBinop;
    _jc_soot_jimple_parser_node_PBinop$sub_refs	soot_jimple_parser_node_PBinop;
    _jc_soot_jimple_parser_node_Node$sub_refs	soot_jimple_parser_node_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_ACmpgBinop$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_node_ACmpgBinop$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_node_Node$sub_nonrefs	soot_jimple_parser_node_Node;
    _jc_soot_jimple_parser_node_PBinop$sub_nonrefs	soot_jimple_parser_node_PBinop;
    _jc_soot_jimple_parser_node_ACmpgBinop$sub_nonrefs	soot_jimple_parser_node_ACmpgBinop;
};

// Object instance structure
struct _jc_soot_jimple_parser_node_ACmpgBinop$object {
	_jc_soot_jimple_parser_node_ACmpgBinop$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_node_ACmpgBinop$vtype	*vtype;
	_jc_soot_jimple_parser_node_ACmpgBinop$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_node_ACmpgBinop$vtype _jc_soot_jimple_parser_node_ACmpgBinop$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_node_ACmpgBinop, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_node_ACmpgBinop$class_object;

#endif	/* _JC_soot_jimple_parser_node_ACmpgBinop_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/parser/node/ACmpgBinop.h <==
// public final class soot.jimple.parser.node.ACmpgBinop

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 525a0407cfed3db4 soot_jimple_parser_node_ACmpgBinop
// @dep_class 73de4e43969ada95 soot_jimple_parser_node_Node
// @dep_class b86441297795c006 soot_jimple_parser_node_PBinop

// header file dependencies
// @dep_header soot_jimple_parser_node_PBinop

#include "soot/jimple/parser/node/PBinop.h"

#ifndef _JC_soot_jimple_parser_node_ACmpgBinop_H_
#define _JC_soot_jimple_parser_node_ACmpgBinop_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_jimple_parser_node_Node$object;
struct _jc_soot_jimple_parser_node_Switch$object;
struct _jc_soot_jimple_parser_node_TCmpg$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_node_ACmpgBinop$sub_refs	_jc_soot_jimple_parser_node_ACmpgBinop$sub_refs;
typedef struct _jc_soot_jimple_parser_node_ACmpgBinop$sub_nonrefs	_jc_soot_jimple_parser_node_ACmpgBinop$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_node_ACmpgBinop$refs	_jc_soot_jimple_parser_node_ACmpgBinop$refs;
typedef struct _jc_soot_jimple_parser_node_ACmpgBinop$nonrefs	_jc_soot_jimple_parser_node_ACmpgBinop$nonrefs;
typedef struct _jc_soot_jimple_parser_node_ACmpgBinop$object	_jc_soot_jimple_parser_node_ACmpgBinop$object;

typedef const struct _jc_soot_jimple_parser_node_ACmpgBinop$vmethods	_jc_soot_jimple_parser_node_ACmpgBinop$vmethods;
typedef const struct _jc_soot_jimple_parser_node_ACmpgBinop$vtable	_jc_soot_jimple_parser_node_ACmpgBinop$vtable;
typedef const struct _jc_soot_jimple_parser_node_ACmpgBinop$vtype	_jc_soot_jimple_parser_node_ACmpgBinop$vtype;

// Constructors
extern void _jc_soot_jimple_parser_node_ACmpgBinop$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpgBinop$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_ACmpgBinop$method$_init$3d21b85fff626a14(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpgBinop$object *, struct _jc_soot_jimple_parser_node_TCmpg$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_jimple_parser_node_ACmpgBinop$method$apply$7d8f74ce7309b216(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpgBinop$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_parser_node_ACmpgBinop$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpgBinop$object *) _JC_JCNI_ATTR;
extern struct _jc_soot_jimple_parser_node_TCmpg$object *_jc_soot_jimple_parser_node_ACmpgBinop$method$getCmpg$a5fb676a25d763b4(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpgBinop$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_ACmpgBinop$method$removeChild$f5fdaab456b88f05(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpgBinop$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_ACmpgBinop$method$replaceChild$f0df61b776b15826(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpgBinop$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_ACmpgBinop$method$setCmpg$f31782e2d53b32dd(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpgBinop$object *, struct _jc_soot_jimple_parser_node_TCmpg$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_jimple_parser_node_ACmpgBinop$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpgBinop$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_parser_node_ACmpgBinop$method_info$apply$7d8f74ce7309b216;
extern _jc_method _jc_soot_jimple_parser_node_ACmpgBinop$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_parser_node_ACmpgBinop$method_info$getCmpg$a5fb676a25d763b4;
extern _jc_method _jc_soot_jimple_parser_node_ACmpgBinop$method_info$removeChild$f5fdaab456b88f05;
extern _jc_method _jc_soot_jimple_parser_node_ACmpgBinop$method_info$replaceChild$f0df61b776b15826;
extern _jc_method _jc_soot_jimple_parser_node_ACmpgBinop$method_info$setCmpg$f31782e2d53b32dd;
extern _jc_method _jc_soot_jimple_parser_node_ACmpgBinop$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_parser_node_ACmpgBinop$vmethods {
	void	(*apply$7d8f74ce7309b216)(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpgBinop$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpgBinop$object *) _JC_JCNI_ATTR;
	struct _jc_soot_jimple_parser_node_TCmpg$object	*(*getCmpg$a5fb676a25d763b4)(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpgBinop$object *) _JC_JCNI_ATTR;
	void	(*removeChild$f5fdaab456b88f05)(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpgBinop$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
	void	(*replaceChild$f0df61b776b15826)(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpgBinop$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
	void	(*setCmpg$f31782e2d53b32dd)(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpgBinop$object *, struct _jc_soot_jimple_parser_node_TCmpg$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpgBinop$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_parser_node_ACmpgBinop$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_node_Node$vmethods	soot_jimple_parser_node_Node;
	_jc_soot_jimple_parser_node_PBinop$vmethods	soot_jimple_parser_node_PBinop;
	_jc_soot_jimple_parser_node_ACmpgBinop$vmethods	soot_jimple_parser_node_ACmpgBinop;
};

// Vtype
struct _jc_soot_jimple_parser_node_ACmpgBinop$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_node_ACmpgBinop$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_ACmpgBinop$sub_refs {
	struct _jc_soot_jimple_parser_node_TCmpg$object	*__5fcmpg__5f;
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_node_ACmpgBinop$refs {
    _jc_soot_jimple_parser_node_ACmpgBinop$sub_refs	soot_jimple_parser_node_ACmpgBinop;
    _jc_soot_jimple_parser_node_PBinop$sub_refs	soot_jimple_parser_node_PBinop;
    _jc_soot_jimple_parser_node_Node$sub_refs	soot_jimple_parser_node_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_ACmpgBinop$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_node_ACmpgBinop$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_node_Node$sub_nonrefs	soot_jimple_parser_node_Node;
    _jc_soot_jimple_parser_node_PBinop$sub_nonrefs	soot_jimple_parser_node_PBinop;
    _jc_soot_jimple_parser_node_ACmpgBinop$sub_nonrefs	soot_jimple_parser_node_ACmpgBinop;
};

// Object instance structure
struct _jc_soot_jimple_parser_node_ACmpgBinop$object {
	_jc_soot_jimple_parser_node_ACmpgBinop$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_node_ACmpgBinop$vtype	*vtype;
	_jc_soot_jimple_parser_node_ACmpgBinop$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_node_ACmpgBinop$vtype _jc_soot_jimple_parser_node_ACmpgBinop$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_node_ACmpgBinop, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_node_ACmpgBinop$class_object;

#endif	/* _JC_soot_jimple_parser_node_ACmpgBinop_H_ */
